
TODO_78_94_31_68: split argrelay into multiple packages

The main benefit is to be able to:
*   track semver compatibility easily (see `semver_notes.md`)
*   reuse them without always downloading everything

All packages may continue to reside in the same single repo (mono repo) with some boundaries.

